==> pymimir-0.9.73.tar.gz: pymimir-0.9.73/include/mimir/search/applicable_action_generators/lifted/event_handlers/statistics.hpp <==
/*
 * Copyright (C) 2023 Dominik Drexler and Simon Stahlberg
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef MIMIR_SEARCH_APPLICABLE_ACTION_GENERATORS_LIFTED_EVENT_HANDLERS_STATISTICS_HPP_
#define MIMIR_SEARCH_APPLICABLE_ACTION_GENERATORS_LIFTED_EVENT_HANDLERS_STATISTICS_HPP_

#include <cstdint>
#include <ostream>
#include <vector>

namespace mimir
{

class LiftedApplicableActionGeneratorStatistics
{
private:
    uint64_t m_num_ground_action_cache_hits;
    uint64_t m_num_ground_action_cache_misses;

    std::vector<uint64_t> m_num_ground_action_cache_hits_per_search_layer;
    std::vector<uint64_t> m_num_ground_action_cache_misses_per_search_layer;
    std::vector<uint64_t> m_num_inapplicable_grounded_actions_per_search_layer;

public:
    LiftedApplicableActionGeneratorStatistics() :
        m_num_ground_action_cache_hits(0),
        m_num_ground_action_cache_misses(0),
        m_num_ground_action_cache_hits_per_search_layer(),
        m_num_ground_action_cache_misses_per_search_layer(),
        m_num_inapplicable_grounded_actions_per_search_layer()
    {
    }

    /// @brief Store information for the layer
    void on_finish_search_layer()
    {
        m_num_ground_action_cache_hits_per_search_layer.push_back(m_num_ground_action_cache_hits);
        m_num_ground_action_cache_misses_per_search_layer.push_back(m_num_ground_action_cache_misses);
    }

    void increment_num_ground_action_cache_hits() { ++m_num_ground_action_cache_hits; }
    void increment_num_ground_action_cache_misses() { ++m_num_ground_action_cache_misses; }

    uint64_t get_num_ground_action_cache_hits() const { return m_num_ground_action_cache_hits; }
    uint64_t get_num_ground_action_cache_misses() const { return m_num_ground_action_cache_misses; }

    const std::vector<uint64_t>& get_num_ground_action_cache_hits_per_search_layer() const { return m_num_ground_action_cache_hits_per_search_layer; }
    const std::vector<uint64_t>& get_num_ground_action_cache_misses_per_search_layer() const { return m_num_ground_action_cache_misses_per_search_layer; }
    const std::vector<uint64_t>& get_num_inapplicable_grounded_actions_per_search_layer() const { return m_num_inapplicable_grounded_actions_per_search_layer; }
};

/**
 * Pretty printing
 */

inline std::ostream& operator<<(std::ostream& os, const LiftedApplicableActionGeneratorStatistics& statistics)
{
    os << "[LiftedApplicableActionGenerator] Number of grounded action cache hits: " << statistics.get_num_ground_action_cache_hits() << std::endl
       << "[LiftedApplicableActionGenerator] Number of grounded action cache hits until last f-layer: "
       << (statistics.get_num_ground_action_cache_hits_per_search_layer().empty() ? 0 : statistics.get_num_ground_action_cache_hits_per_search_layer().back())
       << std::endl
       << "[LiftedApplicableActionGenerator] Number of grounded action cache misses: " << statistics.get_num_ground_action_cache_misses() << std::endl
       << "[LiftedApplicableActionGenerator] Number of grounded action cache misses until last f-layer: "
       << (statistics.get_num_ground_action_cache_misses_per_search_layer().empty() ? 0 :
                                                                                      statistics.get_num_ground_action_cache_misses_per_search_layer().back())
       << std::endl
       << "[LiftedApplicableActionGenerator] Number of generated inapplicable grounded actions until last f-layer: "
       << (statistics.get_num_inapplicable_grounded_actions_per_search_layer().empty() ?
               0 :
               statistics.get_num_inapplicable_grounded_actions_per_search_layer().back());

    return os;
}

}

#endif

==> pymimir-0.12.13.tar.gz: pymimir-0.12.13/include/mimir/search/applicable_action_generators/lifted/event_handlers/statistics.hpp <==
/*
 * Copyright (C) 2023 Dominik Drexler and Simon Stahlberg
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef MIMIR_SEARCH_APPLICABLE_ACTION_GENERATORS_LIFTED_EVENT_HANDLERS_STATISTICS_HPP_
#define MIMIR_SEARCH_APPLICABLE_ACTION_GENERATORS_LIFTED_EVENT_HANDLERS_STATISTICS_HPP_

#include <cstdint>
#include <ostream>
#include <vector>

namespace mimir::search::applicable_action_generator::lifted
{
class Statistics
{
private:
    uint64_t m_num_ground_action_cache_hits;
    uint64_t m_num_ground_action_cache_misses;

    std::vector<uint64_t> m_num_ground_action_cache_hits_per_search_layer;
    std::vector<uint64_t> m_num_ground_action_cache_misses_per_search_layer;
    std::vector<uint64_t> m_num_inapplicable_grounded_actions_per_search_layer;

public:
    Statistics() :
        m_num_ground_action_cache_hits(0),
        m_num_ground_action_cache_misses(0),
        m_num_ground_action_cache_hits_per_search_layer(),
        m_num_ground_action_cache_misses_per_search_layer(),
        m_num_inapplicable_grounded_actions_per_search_layer()
    {
    }

    /// @brief Store information for the layer
    void on_finish_search_layer()
    {
        m_num_ground_action_cache_hits_per_search_layer.push_back(m_num_ground_action_cache_hits);
        m_num_ground_action_cache_misses_per_search_layer.push_back(m_num_ground_action_cache_misses);
    }

    void increment_num_ground_action_cache_hits() { ++m_num_ground_action_cache_hits; }
    void increment_num_ground_action_cache_misses() { ++m_num_ground_action_cache_misses; }

    uint64_t get_num_ground_action_cache_hits() const { return m_num_ground_action_cache_hits; }
    uint64_t get_num_ground_action_cache_misses() const { return m_num_ground_action_cache_misses; }

    const std::vector<uint64_t>& get_num_ground_action_cache_hits_per_search_layer() const { return m_num_ground_action_cache_hits_per_search_layer; }
    const std::vector<uint64_t>& get_num_ground_action_cache_misses_per_search_layer() const { return m_num_ground_action_cache_misses_per_search_layer; }
    const std::vector<uint64_t>& get_num_inapplicable_grounded_actions_per_search_layer() const { return m_num_inapplicable_grounded_actions_per_search_layer; }
};

/**
 * Pretty printing
 */

inline std::ostream& operator<<(std::ostream& os, const Statistics& statistics)
{
    os << "[LiftedApplicableActionGenerator] Number of grounded action cache hits: " << statistics.get_num_ground_action_cache_hits() << std::endl
       << "[LiftedApplicableActionGenerator] Number of grounded action cache hits until last f-layer: "
       << (statistics.get_num_ground_action_cache_hits_per_search_layer().empty() ? 0 : statistics.get_num_ground_action_cache_hits_per_search_layer().back())
       << std::endl
       << "[LiftedApplicableActionGenerator] Number of grounded action cache misses: " << statistics.get_num_ground_action_cache_misses() << std::endl
       << "[LiftedApplicableActionGenerator] Number of grounded action cache misses until last f-layer: "
       << (statistics.get_num_ground_action_cache_misses_per_search_layer().empty() ? 0 :
                                                                                      statistics.get_num_ground_action_cache_misses_per_search_layer().back())
       << std::endl
       << "[LiftedApplicableActionGenerator] Number of generated inapplicable grounded actions until last f-layer: "
       << (statistics.get_num_inapplicable_grounded_actions_per_search_layer().empty() ?
               0 :
               statistics.get_num_inapplicable_grounded_actions_per_search_layer().back());

    return os;
}

}

#endif
